@@ -1,6 +1,4 @@
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import unicode_literals
+from __future__ import print_function, absolute_import, unicode_literals
 import os, sys
 import datetime
 import inspect
@@ -12,7 +10,7 @@ from .commands import register_command, Command, get_answer, get_input, \
 from colorama import init, Fore, Back, Style
 from functools import partial
 
-__version__ = '0.3'
+__version__ = '0.5'
 
 #init(autoreset=True)
 
@@ -65,7 +63,7 @@ class BaseCommandMixin(object):
     indent = 0
 
     def find_package_script(self, indexes, package):
-        files = [os.path.join(package, 'install.py'), '%s.py' % package]
+        files = [os.path.join(package, 'install.ido'), '%s.ido' % package]
         r =  self._find_files(indexes, files)
         if r:
             self.message('Found script file %s of %s' % (r[0], Fore.GREEN+Style.BRIGHT+package), 'prompt')
@@ -107,6 +105,8 @@ class BaseCommandMixin(object):
         """
 
         indexes = self.options.index
+        #add current directory to indexes
+        indexes.insert(0, os.getcwd())
         if 'IDO_INDEXES' in os.environ:
             indexes.extend(os.environ['IDO_INDEXES'].split(';'))
 
@@ -156,7 +156,7 @@ class BaseCommandMixin(object):
             self.settings = {}
 
     def exec_code(self, filename, code, env):
-        from future.utils import exec_
+        from ._compat import exec_
 
         try:
             env['__name__'] = filename
@@ -173,24 +173,24 @@ class BaseCommandMixin(object):
             raise
 
 class InstallCommandMixin(object):
-    def make_env(self, script, code, args=None, options=None):
+    def make_env(self, script, code):
         from . import utils
 
         #load settings file
         d = {}
         d['INDEXES'] = self.indexes
         self.build = d['BUILD'] = '/tmp/ido_packages_build'
-        self.cache = d['CACHE'] = os.path.expandvars('$HOME/.ido/cache')
         #PREFIX will be used to install package with prefix=
         #it can be set in environment variables as IDO_PREFIX
         #or passed in command argumanet -p --prefix
-        self.prefix = d['PREFIX'] = os.path.expanduser(os.path.expandvars(self.options.prefix \
+        self.prefix = d['PREFIX'] = os.path.abspath(os.path.expanduser(os.path.expandvars(self.options.prefix \
                                     or self.settings.get('PREFIX', '') \
-                                    or os.environ.get('IDO_PREFIX', '')))
+                                    or os.environ.get('IDO_PREFIX', ''))))
         self.home = d['HOME'] = os.environ['HOME']
-        self.files = d['FILES'] = os.path.expanduser(os.path.expandvars(self.options.files \
+        self.files = d['FILES'] = os.path.abspath(os.path.expanduser(os.path.expandvars(self.options.files \
                                     or self.settings.get('FILES', '') \
-                                    or os.environ.get('IDO_FILES', '')))
+                                    or os.environ.get('IDO_FILES', ''))))
+
         d['install'] = partial(self.install, indent=self.indent+4)
 
         for k in dir(utils):
@@ -342,6 +342,8 @@ class InstallCommand(BaseCommandMixin, InstallCommandMixin, Command):
                 if p not in self.indexes:
                     self.indexes.insert(0, p)
 
+        self.indexes = [os.path.abspath(p) for p in self.indexes]
+
         if not self.verbose:
             self.quiet = True
         else:
@@ -364,19 +366,19 @@ register_command(InstallCommand)
 
 class ViewPackageCommand(BaseCommandMixin, Command):
     """
-    View install.py of a package
+    View installation script of a package
 
     """
     name = 'view'
-    help = ("View install.py of a package")
+    help = ("View installation script of a package")
     args = 'package'
     option_list = (
         make_option('-i', '--index', dest='index', default=[], action='append',
             help='Package index link, it can be a directory or an url.'),
         make_option('-e', '--editor', dest='editor', default='vi',
-            help='Editor used to open install.py of the package.'),
+            help='Editor used to open installation script of the package.'),
         make_option('-d', '--display', dest='display', default=False, action='store_true',
-            help='Just display install.py content but not edit it.'),
+            help='Just display installation script content but not edit it.'),
         make_option('--nocolor', dest='nocolor', default=False, action='store_true',
             help='Output result without color.'),
    )
@@ -409,7 +411,7 @@ register_command(ViewPackageCommand)
 
 class SearchPackageCommand(BaseCommandMixin, Command):
     """
-    View install.py of a package
+    View installation script of a package
 
     """
     name = 'search'
@@ -471,7 +473,7 @@ register_command(SearchPackageCommand)
 
 class CreateIndexPackageCommand(BaseCommandMixin, Command):
     """
-    View install.py of a package
+    View installation script of a package
 
     """
     name = 'createindex'
@@ -497,11 +499,11 @@ class CreateIndexPackageCommand(BaseCommandMixin, Command):
             if f.startswith('_'):
                 continue
             if os.path.isdir(os.path.join(path, f)):
-                script = os.path.join(path, f, 'install.py')
+                script = os.path.join(path, f, 'install.ido')
                 if os.path.exists(script):
                     packages.append(f)
             else:
-                if f.endswith('.py'):
+                if f.endswith('.ido'):
                     packages.append(f[:-3])
         index_file = os.path.join(path, 'index.txt')
         with open(index_file, 'w') as f:
@@ -617,10 +619,11 @@ class InfoCommand(CallCommand):
                     self.indexes.insert(0, p)
 
         def callback(script, code, env):
+            usage = env.get('usage', '[options] args args')
             option_list = env.get('option_list', [])
             if option_list:
                 parser = OptionParser(prog=self.prog_name,
-                    usage='',
+                    usage='ido call '+subcommand + ' ' + usage,
                     version='',
                     add_help_option = False,
                     option_list=option_list)
